@@ -354,54 +354,54 @@ class Components:
         df_chart['close'] = df['close']
         df_chart['bah'] = df['close'] * (100000 / df_chart.iloc[0].close)
         df_chart['equity_value'] = df['equity_value']
-        df_chart['signal'] = df['signal']
+        df_chart['action'] = df['action']
         df_chart['volume'] = df['volume']
         df_chart['sma'] = df['sma']
 
         _open = []
         _stop_loss = []
         _close_logic = []
-        _profit_taking = []
+        _profit_target = []
 
-        for i in range(len(list(df['signal']))):
-            element = list(df['signal'])[i]
+        for i in range(len(list(df['action']))):
+            element = list(df['action'])[i]
             if element == 'open':
                 _open.append(df_chart.iloc[i].bah)
                 _stop_loss.append(None)
                 _close_logic.append(None)
-                _profit_taking.append(None)
+                _profit_target.append(None)
             elif element == 'stop_loss':
                 _open.append(None)
                 _stop_loss.append(df_chart.iloc[i].bah)
                 _close_logic.append(None)
-                _profit_taking.append(None)
+                _profit_target.append(None)
             elif element == 'close_logic':
                 _open.append(None)
                 _stop_loss.append(None)
                 _close_logic.append(df_chart.iloc[i].bah)
-                _profit_taking.append(None)
-            elif element == 'profit_taking':
+                _profit_target.append(None)
+            elif element == 'profit_target':
                 _open.append(None)
                 _stop_loss.append(None)
                 _close_logic.append(None)
-                _profit_taking.append(df_chart.iloc[i].bah)
+                _profit_target.append(df_chart.iloc[i].bah)
             else:
                 _open.append(None)
                 _stop_loss.append(None)
                 _close_logic.append(None)
-                _profit_taking.append(None)
+                _profit_target.append(None)
 
         df_chart['open'] = _open
         df_chart['stop_loss'] = _stop_loss
         df_chart['close_logic'] = _close_logic
-        df_chart['profit_taking'] = _profit_taking
+        df_chart['profit_target'] = _profit_target
 
         return df_chart
 
 
     def generate_chart_2(self,df_chart,line_colour):
         df_signal = df_chart.copy()
-        df_signal = df_signal.dropna(subset=['signal'])
+        df_signal = df_signal.dropna(subset=['action'])
         df_signal = df_signal.reset_index()
         signal_open_date = []
         signal_open_close = []
@@ -411,18 +411,18 @@ class Components:
 
 
         for i, row in df_signal.iterrows():
-            if row['signal'] == 'open':
+            if row['action'] == 'open':
                 signal_open_date.append(df_signal.iloc[i]['date'])
                 signal_open_close.append(df_signal.iloc[i]['close'])
                 signal_close_date.append(df_signal.iloc[i + 1]['date'])
                 signal_close_close.append(df_signal.iloc[i + 1]['close'])
-                signal_close_reason.append(df_signal.iloc[i + 1]['signal'])
+                signal_close_reason.append(df_signal.iloc[i + 1]['action'])
             else:
                 signal_open_date.append(df_signal.iloc[i - 1]['date'])
                 signal_open_close.append(df_signal.iloc[i - 1]['close'])
                 signal_close_date.append(df_signal.iloc[i]['date'])
                 signal_close_close.append(df_signal.iloc[i]['close'])
-                signal_close_reason.append(df_signal.iloc[i]['signal'])
+                signal_close_reason.append(df_signal.iloc[i]['action'])
 
         df_signal['signal_open_date'] = signal_open_date
         df_signal['signal_open_close'] = signal_open_close
@@ -504,9 +504,9 @@ class Components:
                                       marker=dict(color='rgba(0, 0, 0, 0)', size=8,
                                                   line=dict(color='green', width=1.5)), name='close_logic'), )
         fig_line.add_trace(go.Scatter(mode='markers', customdata=df_signal_final, hovertemplate=hover_template,
-                                      x=df_chart['date'], y=df_chart['profit_taking'], visible='legendonly',
+                                      x=df_chart['date'], y=df_chart['profit_target'], visible='legendonly',
                                       marker=dict(color='rgba(0, 0, 0, 0)', size=8,
-                                                  line=dict(color='red', width=1.5)), name='profit_taking'), )
+                                                  line=dict(color='red', width=1.5)), name='profit_target'), )
         fig_line.add_trace(go.Scatter(mode='markers', customdata=df_signal_final, hovertemplate=hover_template,
                                       x=df_chart['date'], y=df_chart['stop_loss'], visible='legendonly',
                                       marker=dict(color='rgba(0, 0, 0, 0)', size=8,
@@ -551,7 +551,7 @@ class Components:
         df_his[col_pct] = df_his[col_pct].shift(-1 * period)
         df_his[col_pct] = df_his[col_pct] * 100
         df_his[col_pct] = df_his[col_pct].map(lambda x: round(x, 2))
-        df_his = df_his[df_his['signal'] == 'open']
+        df_his = df_his[df_his['action'] == 'open']
 
         df_his[col_rise] = (df_his['high'].rolling(period).max().shift(-1 * (period)) / df_his['close']) - 1
         df_his[col_fall] = (df_his['low'].rolling(period).min().shift(-1 * (period)) / df_his['close']) - 1
