@@ -49,7 +49,6 @@ class Plot:
         add_button_style = components.add_button_style
         add_button_style_disabled = components.add_button_style_disabled
 
-        subchart_dropdown = components.subchart_dropdown
 
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
@@ -63,8 +62,6 @@ class Plot:
                     dbc.Col(html.Div([
                         html.Div(style={'height': '10px', }),
                         sort_method_dropdown,
-                        # html.Div(style={'height': '10px', }),
-                        # subchart_dropdown,
                         html.Div(style={'height': '10px', }),
                         html.Div(id='checklist-container',children=checkbox_div),
                         html.Div('---------------------------------------',style={'margin-left': '15px'}),
